@@ -19,15 +19,12 @@
  */
 package com.google.java.contract.core.agent;
 
-import com.google.java.contract.AllowUnusedImport;
+import com.google.java.contract.ContractImport;
 import com.google.java.contract.Ensures;
 import com.google.java.contract.Invariant;
 import com.google.java.contract.Requires;
-import com.google.java.contract.core.model.ClassName;
 import com.google.java.contract.core.model.ContractKind;
 import com.google.java.contract.core.util.DebugUtils;
-import com.google.java.contract.util.Iterables;
-import com.google.java.contract.util.Predicates;
 import org.objectweb.asm.ClassVisitor;
 import org.objectweb.asm.Label;
 import org.objectweb.asm.MethodVisitor;
@@ -49,7 +46,11 @@ import java.util.List;
  * @author nhat.minh.le@huoc.org (Nhat Minh Lê)
  * @author johannes.rieken@gmail.com (Johannes Rieken)
  */
-@AllowUnusedImport({ ClassName.class, Iterables.class, Predicates.class })
+@ContractImport({
+  "com.google.java.contract.core.model.ClassName",
+  "com.google.java.contract.util.Iterables",
+  "com.google.java.contract.util.Predicates"
+})
 @Invariant({
   "methodStart != null",
   "methodEnd != null",
@@ -133,7 +134,7 @@ public class SpecificationMethodAdapter extends AdviceAdapter {
                                     MethodVisitor mv,
                                     int access, String methodName,
                                     String methodDesc) {
-    super(Opcodes.ASM4, mv, access, methodName, methodDesc);
+    super(Opcodes.ASM5, mv, access, methodName, methodDesc);
 
     methodStart = new Label();
     methodEnd = new Label();
@@ -543,10 +544,10 @@ public class SpecificationMethodAdapter extends AdviceAdapter {
   protected void invokeContractMethod(MethodNode contractMethod) {
     if (!statik) {
       mv.visitMethodInsn(INVOKESPECIAL, className,
-                         contractMethod.name, contractMethod.desc);
+                         contractMethod.name, contractMethod.desc, false);
     } else {
       mv.visitMethodInsn(INVOKESTATIC, className,
-                         contractMethod.name, contractMethod.desc);
+                         contractMethod.name, contractMethod.desc, false);
     }
   }
 
